@@ -25,6 +25,8 @@
 #include <QButtonGroup>
 #include <QAbstractButton>
 
+#include <KLocalizedString>
+
 // Konsole
 #include "ui_HistorySizeWidget.h"
 
@@ -47,21 +49,18 @@ HistorySizeWidget::HistorySizeWidget(QWidget* parent)
 
     // focus and select the spinner automatically when appropriate
     _ui->fixedSizeHistoryButton->setFocusProxy(_ui->historyLineSpinner);
-    connect(_ui->fixedSizeHistoryButton , SIGNAL(clicked()) ,
-            _ui->historyLineSpinner , SLOT(selectAll()));
+    connect(_ui->fixedSizeHistoryButton , &QRadioButton::clicked , _ui->historyLineSpinner , &KPluralHandlingSpinBox::selectAll);
 
     QButtonGroup* modeGroup = new QButtonGroup(this);
     modeGroup->addButton(_ui->noHistoryButton);
     modeGroup->addButton(_ui->fixedSizeHistoryButton);
     modeGroup->addButton(_ui->unlimitedHistoryButton);
-    connect(modeGroup, SIGNAL(buttonClicked(QAbstractButton*)),
-            this, SLOT(buttonClicked(QAbstractButton*)));
+    connect(modeGroup, static_cast<void(QButtonGroup::*)(QAbstractButton*)>(&QButtonGroup::buttonClicked), this, &Konsole::HistorySizeWidget::buttonClicked);
 
     _ui->historyLineSpinner->setSuffix(ki18ncp("Unit of scrollback", " line", " lines"));
     this->setLineCount(HistorySizeWidget::DefaultLineCount);
 
-    connect(_ui->historyLineSpinner, SIGNAL(valueChanged(int)),
-            this, SIGNAL(historySizeChanged(int)));
+    connect(_ui->historyLineSpinner, static_cast<void(KPluralHandlingSpinBox::*)(int)>(&KPluralHandlingSpinBox::valueChanged), this, &Konsole::HistorySizeWidget::historySizeChanged);
 }
 
 HistorySizeWidget::~HistorySizeWidget()
@@ -112,4 +111,3 @@ int HistorySizeWidget::lineCount() const
     return _ui->historyLineSpinner->value();
 }
 
-#include "HistorySizeWidget.moc"
